
clear
set more off
capture set max_memory 500M 
capture set mem 500M		

cap log close

**********************************************************************************
*
* CREATING WAVE 4 BASIC VARIABLES
*
**********************************************************************************

use "$y4data/hh_sec_a.dta", clear
count

keep y4_hhid-hh_a18_3

rename hh_a01_1 region
rename hh_a02_1 district
rename hh_a03_1 ward
rename hh_a03_3a village
rename hh_a04_1 ea

*~*~*~*~*~*~*~*~*~*~*
* HOUSEHOLD WEIGHT 	*
*~*~*~*~*~*~*~*~*~*~*
rename y4_weight hhweight

count if hhweight==.

label var hhweight "Sampling weights, y4_weight"

*~*~*~*~*~*~*~*~*~*~*
* URBAN/RURAL/MIXED	*
*~*~*~*~*~*~*~*~*~*~*
describe y4_rural
tab y4_rural, m
/* Note: Currently all missing. Will use domain to make urban/rural
classification for households in new sample */

gen urban = 1 if domain==3		// Mainland rural
replace urban = 2 if (domain==1 | domain==2)	// Mainland DSM & Other Urban

count if missing(ward)

** Use ward codes to determine urban/rural for Zanzibar households **
tostring(ward), gen(ward_str)
replace ward_str = "0" + ward_str if length(ward_str) == 2

** Use EA codes to determine rural/urban for mixed wards **
tostring(ea), gen(ea_str)
replace ea_str = "00" + ea_str if length(ea_str) == 1
replace ea_str = "0" + ea_str if length(ea_str) == 2

replace urban = 2 if substr(ward_str,3,1) == "1" & domain==4
replace urban = 1 if substr(ward_str,3,1) == "2" & domain==4
replace urban = 2 if substr(ward_str,3,1) == "3" & substr(ea_str,1,1) == "0" & domain==4 /* rural hh in mixed ward */
replace urban = 1 if substr(ward_str,3,1) == "3" & substr(ea_str,1,1) == "3" & domain==4 /* urban hh in mixed ward */

label define URBAN 1 "Rural" 2 "Urban"
label value urban URBAN
label var urban "Urban or Rural areas"

tab urban, m

*~*~*~*~*
* AREA  *
*~*~*~*~*

gen area=1 if region == 7
replace area=2 if region != 7 & urban == 2
replace area=3 if region != 7 & urban == 1
replace area=4 if region != 7 & inrange(region,51,55)

label define AREA 1 "Dar es Salaam" 2 "Rest of urban" 3 "Rural" 4 "Zanzibar"
label val area AREA
label var area "Area"
tab area, m

** Check against domain variable for new sample **
gen area2 = domain
assert area2==area
drop area2

*~*~*~*~*~*~*
* MAINLAND 	*
*~*~*~*~*~*~*

* Mainland is region code that is not in the 50s *
* Region code 51-55 is Zanzibar *

gen mainland = 1 if inrange(region,1,25)
replace mainland = 2 if inrange(region,51,55)

label define MAINLAND 1 "Mainland" 2 "Zanzibar"
label value mainland MAINLAND
label var mainland "Mainland or Zanzibar"

tab mainland, m

**-------- NEW HOUSEHOLDS -----------***
** CHECK THAT VALUES FOR DOMAIN AND STRATA ARE EQUIVALENT **
tab domain if hh_a06>999 & !missing(hh_a06), m

label list DOMAIN

gen strata = domain if hh_a06>999 & !missing(hh_a06)
label define STRATA2 1 "Dar es Salaam" 2 "Rest of urban" 3 "Rural" 4 "Zanzibar"
label var strata Strata


gen cluster = clusterid if hh_a06>999 & !missing(hh_a06)
label var cluster Cluster

*~*~*~*~*~*~*~*~*~*~*
* DATE OF INTERVIEW *
*~*~*~*~*~*~*~*~*~*~*

* Cleaning 
replace hh_a18_3 = 2015 if inlist(y4_hhid, "2164-001", "2182-001", "2887-001", "4554-001", "8277-001", "4102-001")
replace hh_a18_2 = 1 if inlist(y4_hhid, "2164-001", "2887-001")
replace hh_a18_2 = 2 if inlist(y4_hhid, "2182-001")
replace hh_a18_2 = 7 if inlist(y4_hhid, "8277-001")
replace hh_a18_2 = 4 if inlist(y4_hhid, "4554-001")
replace hh_a18_2 = 9 if inlist(y4_hhid, "4102-001")
replace hh_a18_2 = 11 if inlist(y4_hhid, "3662-001", "4211-001")
replace hh_a18_2 = 11 if inlist(y4_hhid, "3662-001", "4211-001")
replace hh_a18_3 = 2014 if inlist(y4_hhid, "3662-001", "4211-001")

summ hh_a18*
gen m = hh_a18_2
gen y = hh_a18_3
tab m y, m

gen intmonth = m
gen intyear  = y
label var intmonth "Month of interview"
label var intyear "Year of interview"
tab intmonth intyear, m

gen     month = .
replace month = intmonth - 9 if intyear==2014 & inrange(intmonth,10,12)
replace month = intmonth + 3 if intyear==2015 & inrange(intmonth,1,9)

recode month .=12 if intyear==2015 & inrange(intmonth,10,12)
recode month .=12 if intyear==2016

label define month 1 "October 2014" 2 November 3 December 4 January 5 February 6 March ///
	7 April 8 May 9 June 10 July 11 August 12 "September 2015", replace
label var month Month
label values month month

tab month, m

* listing cases with missing or incorrect dates
list y4_hhid region district ward ea hh_a18* intmonth if month==., nol sep(0)

* Creating a quarter variable
tab month, m
label list month
gen quarter = irecode(month,3,6,9,12) + 1

label define quarter 1 "Oct-Dec 2014" 2 "Jan-Mar 2015" 3 "Apr-Jun 2015" 4 "Jul-Sep 2015", replace
label var quarter "Quarter of fieldwork"
label val quarter quarter

tab quarter, m
tabstat month, by(quarter) s(min max)

*~*~*~*~*~*~*~~*~*~*~*~*~*~*~*
* HOUSEHOLD SIZE/ADULT EQUIV *
*~*~*~*~*~*~*~~*~*~*~*~*~*~*~*

preserve

	use "$y4data/hh_sec_b.dta", clear

	renpfix hh_b b

*******************************************
* How many households are in the roster?
*******************************************

egen x = group(y4_hhid)
summarize x
tab y4_hhid if x==., m

bysort y4_hhid : gen first = cond(_n==1,1,0)
tab first, m
count if first==1
count if first==1 & x==.

***********************
* Adult Equivalents
***********************

	gen sex = b02
	gen age = b04
	summ sex age
	tab1 sex age, m

/* Adult equivalence factors created using WHO nutritional weight standards
   Collier et al, 1986 */

	gen adulteqfactor = .
	replace adulteqfactor = 0.40 if inrange(age,0,2)
	replace adulteqfactor = 0.48 if inrange(age,3,4)
	replace adulteqfactor = 0.56 if inrange(age,5,6)
	replace adulteqfactor = 0.64 if inrange(age,7,8)
	replace adulteqfactor = 0.76 if inrange(age,9,10)
	replace adulteqfactor = 0.80 if inrange(age,11,12)  & sex==1
	replace adulteqfactor = 0.88 if inrange(age,11,12)  & sex==2
	replace adulteqfactor = 1.00 if inrange(age,13,14)
	replace adulteqfactor = 1.20 if inrange(age,15,18)  & sex==1
	replace adulteqfactor = 1.00 if inrange(age,15,18)  & sex==2
	replace adulteqfactor = 1.00 if inrange(age,19,59)  & sex==1
	replace adulteqfactor = 0.88 if inrange(age,19,59)  & sex==2
	replace adulteqfactor = 0.88 if inrange(age,60,108) & sex==1
	replace adulteqfactor = 0.72 if inrange(age,60,105) & sex==2
	tab adulteqfactor, m

	list if adulteqfactor==.

	* Adult equivalence factors adjusted for males age range 60-105 to 60-108

	inspect adulteqfactor
	summ adulteqfactor, detail

	gen femalehead = 1 if b05==1 & b02==2
	replace femalehead = 0 if missing(femalehead)

	tab femalehead, m

	collapse (max) femalehead (count) hhsize=indidy4 (sum) adulteq=adulteqfactor, by(y4_hhid)

	label var femalehead "Female headed household"
	label var hhsize "Household size"
	label var adulteq "Adult-equivalents in the household"

	tempfile roster
	save `roster', replace

restore

merge 1:1 y4_hhid using `roster'
* assert _m==3 // excess households were drop so it won't be a perfect match
drop _m

**************
* summary
**************

keep y4_hhid cluster strata hhweight region district ward village ea month quarter urban area mainland femalehead ///
	 hhsize adulteq intyear intmonth quarter

order y4_hhid cluster strata hhweight region district ward village ea month quarter urban area mainland femalehead ///
	  hhsize adulteq intyear intmonth quarter

compress
describe
sort y4_hhid

save "$output/basicvars_y4.dta", replace

clear
capture log close
