
clear all
set mem 500m
set more off
pause on

cap log close

/**********************************************************************
*NPSY5 - HOUSING
***********************************************************************/
***********************************
* NPS4
***********************************

use "$y4data/hh_sec_i.dta", clear

	keep y4_hhid hh_i*
	renpfix hh_i i
	sort y4_hhid

	merge 1:1 y4_hhid using "$output/basicvars_y4.dta"
	tab _merge
	keep if _m==3
	drop _merge

* MAIN SOURCE OF DRINKING WATER
	d i19 i29
	label list HH_I19 HH_I29
	summ i19 i29
	tab1 i19 i29, m
	tab i19 [aw=hhweight]
	tab i29 [aw=hhweight]

	tab i19 if inlist(i19,8,9)   [aw=hhweight], m
	tab i19 if inlist(i19,10,11) [aw=hhweight], m
	tab i29 if inlist(i29,8,9)   [aw=hhweight], m
	tab i29 if inlist(i29,10,11) [aw=hhweight], m

* LOCATION OF DRINKING WATER SOURCE
	d i20 i30
	label list HH_I20 HH_I30
	summ i20 i30
	tab i20 [aw=hhweight]
	tab i30 [aw=hhweight]

* TOILET FACILITIES
	d i12
	label list HH_I12
	summ i12
	tab i12, m

* ALTERNATIVE SOURCES OF ENERGY FOR COOKING
	d i16
	label list HH_I16
	summ i16
	tab i16, m

* ELECTRICITY
	d i17
	label list HH_I17
	summ i17
	tab i17, m

* DWELLING CHARACTERISTICS
	gen walls = inlist(i08, 5, 6)
	gen roof  = inlist(i09, 3,4,5,6)
	gen floor = inlist(i10, 2)
	
	keep strata cluster area urban mainland region hhweight hhsize i12-i14 i16 i17 i19 i20 i22 i27 i29 i30 y4_hhid walls roof floor

	gen round = 4
	tempfile housing4
	save `housing4', replace
	
***********************************
* NPS5
***********************************

use "$y5data/hh_sec_i.dta", clear

	keep y5_hhid hh_i*
	renpfix hh_i i
	sort y5_hhid

	merge 1:1 y5_hhid using "$output/basicvars_y5.dta"
	tab _merge
	keep if _m==3
	drop _merge

* MAIN SOURCE OF DRINKING WATER
	d i19 i29
	label list hh_i19 hh_i29
	summ i19 i29
	tab1 i19 i29, m
	tab i19 [aw=hhweight]
	tab i29 [aw=hhweight]

	tab i19 if inlist(i19,8,9)   [aw=hhweight], m
	tab i19 if inlist(i19,10,11) [aw=hhweight], m
	tab i29 if inlist(i29,8,9)   [aw=hhweight], m
	tab i29 if inlist(i29,10,11) [aw=hhweight], m

* LOCATION OF DRINKING WATER SOURCE
	d i20 i30
	label list hh_i20 hh_i30
	summ i20 i30
	tab i20 [aw=hhweight]
	tab i30 [aw=hhweight]

* TOILET FACILITIES
	d i12
	label list hh_i12
	summ i12
	tab i12, m

* ALTERNATIVE SOURCES OF ENERGY FOR COOKING
	d i16
	label list hh_i16
	summ i16
	tab i16, m

* ELECTRICITY
	d i17
	label list hh_i17
	summ i17
	tab i17, m

* DWELLING CHARACTERISTICS
	gen walls = inlist(i08, 5, 6)
	gen roof  = inlist(i09, 3,4,5,6)
	gen floor = inlist(i10, 2)

	keep strata cluster area urban mainland region hhweight hhsize i12-i14 i16 i17 i19 i20 i22 i27 i29 i30 y5_hhid tracking_class walls roof floor

	gen round = 5

***********************************
* appending round 4 + 5
***********************************

append using `housing4'
tab round, m

***************************************
* SHARED/NOT SHARED TOILET FACILITIES *
***************************************

* SHARED/NOT SHARED TOILET FACILITY *
gen shared = .
replace shared = 1 if i13==1 & (round==4|round==5)
replace shared = 0 if i13==2 & (round==4|round==5)

tab shared, m
lab var shared "Shared/not shared toilet facility"

label def SHARED 1 "Shared" 0 "Not shared", add

* NUMBER OF HOUSEHOLDS SHARED WITH *
recode i14 	(1	 	= 1 "Shared with 1 household") 		///
			(2/4 	= 2 "Shared with 2-4 households") 	///
			(5/33 	= 3 "Shared with 5+ households"), gen(shared_hh) label(SHARED_HH)

replace shared_hh=0 if i13 == 2

**********************
* TOILET FACILITIES
**********************

	* TOILET *
	gen toilet = .
	* Pour/flush toilet *
	replace toilet = 1 if (round==4|round==5) & inlist(i12,6,7)

	* VIP *
	replace toilet = 2 if (round==4|round==5) & i12==5

	* Pit latrine *
	replace toilet = 3 if (round==4|round==5) & inlist(i12,2,3,4)

	* Other *
	replace toilet = 4 if (round==4|round==5) & inlist(i12,8,9)

	* No toilet *
	replace toilet = 5 if (round==4|round==5) & i12==1

	label var toilet "Toilet facilities"
	label define TOILET 1 "Flush/pour toilet" 		///
						2 "VIP" 					///
						3 "Pit latrine w/" 			///
						4 "Other" 					///
						5 "None", replace
	label value toilet TOILET
	tab toilet round, m
	
* TOILET TYPE (DETAILED) *
	clonevar toilet_type = i12
	tab toilet_type round, m
	
	foreach num of numlist 1/9 {
		gen toilet_type`num' = (toilet_type == `num')
		recode toilet_type`num' (1=100)
			}
			
	label var toilet_type1 "NO TOILET"
	label var toilet_type2 "PIT LATRINE WITHOUT SLAB (OPEN PIT)"
	label var toilet_type3 "PIT LATRINE WITH SLAB (NOT WASHABLE)"
	label var toilet_type4 "PIT LATRINE WITH SLAB (WASHABLE)"
	label var toilet_type5 "VIP"
	label var toilet_type6 "POUR FLUSH"
	label var toilet_type7 "FLUSH TOILET"
	label var toilet_type8 "ECOSAN"
	label var toilet_type9 "OTHER TOILET TYPE"

** BASIC SANITATION **
	gen basicsanit = inrange(toilet,1,3) if toilet!=.
	recode basicsanit 1=100
	tab basicsanit round, m
	label var basicsanit "Basic sanitation"

** MARK IMPROVED TOILET FACILITIES FOR ROUND 4/5
	gen improved_toilet = 0 if inrange(round,4,5)
	replace improved_toilet = 100 if inrange(i12,3,8) & shared==0 & (round==4|round==5)

*******************************************************
*~*~*~*~*~*~*~*~* END DATA PREP *~*~*~*~*~*~*~*~*~*~*~*
*******************************************************

***********************************
* MAIN SOURCE OF DRINKING WATER
* RAINY SEASON
***********************************

	gen dwaterrainy = .

/* NOTE: Type of water source and location of water source
were separated into two questions in NPS4 and NPS5. Will need to use I19 and I20
to generate this variable */

	replace dwaterrainy = 1 if i19==1 & i20==1 & (round==4|round==5)
	replace dwaterrainy = 2 if i19==1 & i20==2 & (round==4|round==5)
	replace dwaterrainy = 3 if i19==1 & i20==4 & (round==4|round==5)
	replace dwaterrainy = 4 if i20==3 & (round==4|round==5)
	replace dwaterrainy = 5 if inlist(i19,8,9,10) & (round==4|round==5)
	replace dwaterrainy = 6 if inlist(i19, 3)
	replace dwaterrainy = 7 if inlist(i19, 5)
	replace dwaterrainy = 8 if i19==11 & (round==4|round==5)
	replace dwaterrainy = 9 if i19==7 & (round==4|round==5)
	replace dwaterrainy = 10 if i19==12 & (round==4|round==5)

	label var dwaterrainy "Source of drinking water during rainy season"
	label val dwaterrainy dwater
	label define dwater 					///
		 1 "Piped water inside dwelling" 	///
		 2 "Private outside standpipe/tap" 	///
		 3 "Public standpipe/tap" 			///
		 4 "Neighbouring household" 		///
		 5 "Water vendor*" 					///
		 6 "Protected well" 				///
		 7 "Protected spring" 				///
		 8 "River, lake, spring, pond" 		///
		 9 "Rainwater" 						///
		10 "Other"

	tab dwaterrainy round, m

* Generate version that matches Y4
gen safewaterrainy = 0
replace safewaterrainy = 100 if round==4 & inlist(i19,1,2,3,5,8)
replace safewaterrainy = 100 if round==5 & inlist(i19,1,2,3,5,8)
replace safewaterrainy = . if (round==4 & inrange(i19,1,12)!=1) | (round==5  & inrange(i19,1,12)!=1)

tab safewaterrainy round, m
label var safewaterrainy "Safe drinking water source (rainy) - Y4 DEFINITION"

* Generate CORRECTED version of safewaterrainy
gen safewaterrainy2 = 0
replace safewaterrainy2 = 100 if round==4 & inlist(dwaterrainy,1,2,3,6) | i19==8
replace safewaterrainy2 = 100 if round==5 & inlist(dwaterrainy,1,2,3,6) | i19==8

replace safewaterrainy2 = . if (round==4 & inrange(i19,1,12)!=1) | (round==5  & inrange(i19,1,12)!=1)

tab safewaterrainy2 round, m
label var safewaterrainy2 "Safe drinking water source (rainy) - ALT DEFINTION"

** Improved source drinking water
** NOTE: Rain water is considered an improved source of water but not included
** above as a safe source of drinking water

* Generate version that matches Y4
gen improved_rainy = 0
replace improved_rainy = 100 if round==4 & inlist(i19,1,2,3,5,7,8)
replace improved_rainy = 100 if round==5 & inlist(i19,1,2,3,5,7,8)
replace improved_rainy = . if (round==4 & inrange(i19,1,12)!=1) | (round==5 & inrange(i19,1,12)!=1)

tab improved_rainy round, m
label var improved_rainy "Improved source drinking water (rainy) - Y4 DEFINITION"

* Generate CORRECTED version of improved_rainy
gen improved_rainy2 = 0
replace improved_rainy2 = 100 if round==4 & inlist(dwaterrainy,1,2,3,5,6,9) | i19==8
replace improved_rainy2 = 100 if round==5 & inlist(dwaterrainy,1,2,3,5,6,9) | i19==8
replace improved_rainy2 = . if (round==4 & inrange(i19,1,12)!=1) | (round==5 & inrange(i19,1,12)!=1)

tab improved_rainy2 round, m
label var improved_rainy2 "Improved source drinking water (rainy) - ALT DEFINITION"

***********************************
* main source of drinking water
* dry season
***********************************

gen dwaterdry = .

/* NOTE: Type of water source and location of water source
were separated into two questions in NPS4 and NPS5. Will need to use I19 and I20
to generate this variable */

replace dwaterdry = 1 if i29==1 & i30==1 & (round==4|round==5)
replace dwaterdry = 2 if i29==1 & i30==2 & (round==4|round==5)
replace dwaterdry = 3 if i29==1 & i30==4 & (round==4|round==5)
replace dwaterdry = 4 if i30==3 & (round==4|round==5)
replace dwaterdry = 5 if inlist(i19,8,9,10) & (round==4|round==5)
replace dwaterdry = 6 if inlist(i19, 3)
replace dwaterdry = 7 if inlist(i19, 5)
replace dwaterdry = 8 if i29==11 & (round==4|round==5)
replace dwaterdry = 9 if i29==7 & (round==4|round==5)
replace dwaterdry = 10 if i29==12 & (round==4|round==5)

** DID NOT CHANGE WATER SOURCE BETWEEN RAINY AND DRY SEASON (NPS4 and NPS5) **
replace dwaterdry=dwaterrainy if i27 == 1 & missing(i29)

label var dwaterdry "Source of drinking water during dry season"
label val dwaterdry dwater
tab dwaterdry round, m


* Generate version that matches Y4
gen safewaterdry = 0
// Changed water source in dry season
replace safewaterdry = 100 if round==4 & inlist(i29,1,2,3,5,8) & i27==2
replace safewaterdry = 100 if round==5 & inlist(i29,1,2,3,5,8) & i27==2
// Did not change water source in rainy season - take response for rainy season source
replace safewaterdry = safewaterrainy if round==4 & i27==1
replace safewaterdry = safewaterrainy if round==5 & i27==1
label var safewaterdry "Safe drinking water source (dry) - Y4 DEFINITION"
tab safewaterdry round, m

* Generate CORRECTED version of safewaterdry
gen safewaterdry2 = 0
// Changed water source in dry season
replace safewaterdry2 = 100 if round==4 & (inlist(dwaterdry,1,2,3,6) | i29==8) & i27==2
replace safewaterdry2 = 100 if round==5 & (inlist(dwaterdry,1,2,3,6) | i29==8) & i27==2
// Did not change water source in rainy season - take response for rainy season source
replace safewaterdry2 = safewaterrainy2 if round==4 & i27==1
replace safewaterdry2 = safewaterrainy2 if round==5 & i27==1
label var safewaterdry2 "Safe drinking water source (dry) - ALT DEFINITION"
tab safewaterdry2 round, m

** Improved source drinking water
** NOTE: Rain water is considered an improved source of water

* Generate version that matches Y4
gen improved_dry = 0
replace improved_dry = 100 if round==4 & inlist(i29,1,2,3,5,7,8) & i27==2
replace improved_dry = 100 if round==5 & inlist(i29,1,2,3,5,7,8) & i27==2
// Did not change source of drinking water during dry season
replace improved_dry = improved_rainy if round==4 & i27==1
replace improved_dry = improved_rainy if round==5 & i27==1
tab improved_dry round, m
label var improved_dry "Improved source drinking water (dry) - Y4 DEFINITION"

* Generate CORRECTED version of safewaterdry
gen improved_dry2 = 0
replace improved_dry2 = 100 if round==4 & (inlist(dwaterdry,1,2,3,5,6,9) | i29==8) & i27==2
replace improved_dry2 = 100 if round==5 & (inlist(dwaterdry,1,2,3,5,6,9) | i29==8) & i27==2
// Did not change source of drinking water during dry season
replace improved_dry2 = improved_rainy if round==4 & i27==1
replace improved_dry2 = improved_rainy if round==5 & i27==1
tab improved_dry2 round, m
label var improved_dry2 "Improved source drinking water (dry) - ALT DEFINITION"

***********************************
* major fuel source for cooking
***********************************

gen fuelcook = .
replace fuelcook = i16	   	if (round==4|round==5)
label var fuelcook "Major source of fuel for cooking"
label val fuelcook fuelcook
label define fuelcook ///
	1 "Firewood"	///
	2 "Paraffin" 	///
	3 "Electricity" ///
	4 "Gas"	 		///
	5 "Charcoal"	 ///
	6 "Animal residual" ///
	7 "Gas (biogas)" ///
	8 Other
tab fuelcook, m
tab fuelcook round, m

gen altfuel = .
replace altfuel = 1 if inlist(fuelcook,3,4,7,8)
replace altfuel = 2 if inlist(fuelcook,1,5)
replace altfuel = 3 if inlist(fuelcook,2,6)
label var altfuel "Fuels used for cooking"
label val altfuel altfuel
label define altfuel 1 Alternative 2 WoodCharcoal 3 ParaffinDung
tab altfuel, m
tab altfuel round, m

gen altfuel2 = altfuel
recode altfuel2 1=100 2/3=0

label var altfuel2 "HH uses alternate fuel for cooking"

***********************************
* electricity
***********************************

gen electricity = 0
replace electricity = 100 if (round==4|round==5) & i17==1

label var electricity "Electricity for lighting"
label val electricity electricity
label define electricity 100 Yes 0 No
tab electricity, m
tab electricity round, m


****************************
* confidence intervals NPS4
****************************
preserve
	keep if round==4

	keep y4_hhid /*y3_hhid*/ strata cluster hhweight electricity altfuel2 	///
		safewaterrainy safewaterdry basicsanit urban mainland area round	///
		improved_toilet improved_rainy improved_dry walls floor roof
	tempfile hrd4
	save `hrd4', replace
	saveold "$output\housing_y4", replace
restore

****************************
* confidence intervals NPS5
****************************
preserve
	keep if round==5

	keep y5_hhid y4_hhid strata cluster hhweight electricity altfuel2 		///
		safewaterrainy safewaterdry basicsanit urban mainland area round	///
		improved_toilet improved_rainy improved_dry walls floor roof
	tempfile hrd5
	save `hrd5', replace
	saveold "$output\housing_y5", replace

restore
