

clear all
capture set max_memory 500M /* for stata 12 */
capture set mem 500M		/* for stata 11 */
set more off
pause on

***********************************
* NPS4
***********************************

use "$y4data/hh_sec_j3.dta", clear
gen foodgroup_yes = (hh_j08_3>0 & hh_j08_3!=.)
collapse (sum) foodgroup_yes, by(y4_hhid)
rename foodgroup_yes diet_diversity
label var diet_diversity "Number of food groups consumed in past week (out of 10)"
tempfile dietdiversity
save `dietdiversity', replace

* merging with household data
merge m:1 y4_hhid using "$output/basicvars_y4.dta", update

gen round = 4
tab round, m

tempfile round4
save `round4', replace

***********************************
* NPS5
***********************************


use "$y5data/hh_sec_j3.dta", clear
gen foodgroup_yes = (hh_j08>0 & hh_j08!=.)
gen vegetable_yes = (hh_j08>0 & hh_j08!=.) if itemcode == 4
gen fruits_yes = (hh_j08>0 & hh_j08!=.) if itemcode == 6
gen balanced_yes = .
replace balanced_yes = (hh_j08>0 & hh_j08!=.) if inlist(itemcode, 1, 2)
replace balanced_yes = (hh_j08>0 & hh_j08!=.) if inlist(itemcode, 3, 5)
replace balanced_yes = (hh_j08>0 & hh_j08!=.) if itemcode == 4
replace balanced_yes = (hh_j08>0 & hh_j08!=.) if itemcode == 6
replace balanced_yes = (hh_j08>0 & hh_j08!=.) if inlist(itemcode, 8, 9)
collapse (sum) foodgroup_yes vegetable_yes fruits_yes balanced_yes, by(y5_hhid)
recode balanced_yes (0/4 = 0) (5/8 = 100), gen(balanced)
rename foodgroup_yes diet_diversity
label var diet_diversity "Number of food groups consumed in past week"
label var balanced "Ate a balanced meal in the last week (5 main food groups)"
tempfile dietdiversity
save `dietdiversity', replace

* merging with household data
merge m:1 y5_hhid using "$output/basicvars_y5.dta", update

sort y5_hhid

gen round = 5
tab round, m

* append round 4 data
append using `round4'
tab round, m

//	Keep Only Variables Needed for Analysis
	keep y5_hhid y4_hhid round diet_diversity 
	order y5_hhid y4_hhid
	saveold "$output\food_security", replace
	
	
	
