
****************************** WAVE 5 ADDITIONAL DATA PREPARATION ****************************************

*ADD HOUSING VARIABLES HERE AS WELL
	//	Basic Variables 
		use "$output\basicvars_y5", clear 
		tempfile w5_basicvars
		save `w5_basicvars', replace		
		
	//	Bring the Consumption and Poverty Variables 
		use "$y5data\consumption_real_y5", clear 
			foreach var of varlist femalehead - expmR_pae {
				rename `var' y5_`var'
			}
		mmerge y5_hhid using `w5_basicvars'

		save `w5_basicvars', replace				

	//	Bring in the Housing Variables
		use "$output\housing_y5", clear
			foreach var of varlist roof floor walls basicsanit - electricity {
				rename `var' y5_`var'
			}
		mmerge y5_hhid using `w5_basicvars'
		
		save `w5_basicvars', replace				
		
	//	Bring in the Food Security Variables
		use "$output\food_security", clear
		keep if round == 5
			foreach var of varlist diet_diversity {
				rename `var' y5_`var'
			}
		mmerge y5_hhid using `w5_basicvars'
		
		save `w5_basicvars', replace
		
	//	Call the Household Roster 
		use "$y5data\hh_sec_b", clear	
		
		gen sex = hh_b02
			recode sex (1=0 )
			recode sex (2=1 )
		gen age = hh_b04
		summ sex age
		tab1 sex age, m
		gen married = inlist(hh_b19,1,2,3)
		gen h_age = age if hh_b05==1
		bysort y5_hhid: egen head_age = max(h_age)
		gen h_married = married if hh_b05==1
		bysort y5_hhid: egen head_married = max(h_married)
		gen youth = inrange(age,15,30)
		
		keep y5_hhid indidy5 hh_b06 sex age married youth head_age head_married
		mmerge y5_hhid using `w5_basicvars'
		 tempfile w5_indiv
		 save `w5_indiv', replace
		
		
	//	Call the Education Variable
		use "$y5data\hh_sec_c", clear	
		mmerge y5_hhid indidy5 using "$y5data\hh_sec_b"

		gen attending = hh_c05==1
		tab attending, m

		gen level = 9
		replace level = 1 if hh_c07==1
		replace level = 2 if inrange(hh_c07,11,17)
		replace level = 3 if inrange(hh_c07,21,24)
		replace level = 4 if inrange(hh_c07,41,45)
		label define level 1 Preprimary 2 Primary 3 Secondary 4 Uni 9 Other
		label val level level
				
		gen primary = level == 2
		gen secondary = level == 3
		gen tertiary = level == 4
		gen secondary_plus = (secondary==1 | tertiary==1)
		
		gen h_pri_edu = primary if hh_b05==1
		gen h_sec_edu = secondary if hh_b05==1
		gen h_sec_plus_edu = secondary_plus if hh_b05==1
		gen h_ter_edu = tertiary if hh_b05==1
		bysort y5_hhid: egen head_pri_edu = max(h_pri_edu)
		bysort y5_hhid: egen head_sec_edu = max(h_sec_edu)
		bysort y5_hhid: egen head_sec_plus_edu = max(h_sec_plus_edu)
		bysort y5_hhid: egen head_ter_edu = max(h_ter_edu)
		
		label val level level
		
		keep y5_hhid indidy5 attending level primary secondary tertiary secondary_plus head_pri_edu ///
			 head_sec_edu head_sec_plus_edu head_ter_edu
		
		mmerge y5_hhid indidy5 using `w5_indiv'
		save `w5_indiv', replace
	
	//	Migration 
		use "$y5data\hh_sec_b.dta" , clear
			gen migrate = (hh_b26<99) & hh_b26!=.
			gen migrat_10 = inrange(hh_b26,0,10)
			gen migrat_5 = inrange(hh_b26,0,5)
		mmerge y5_hhid using "$y5data\hh_sec_a.dta" 
			gen dist_migrat = (hh_b27_3!=hh_a02_1) if migrate==1
			gen reg_migrat = (hh_b27_2!=hh_a01_1) if migrate==1
			gen reg_5_migrat = (migrat_5==1 & reg_migrat==1) 
			gen reg_10_migrat = (migrat_10==1 & reg_migrat==1)
			gen dist_5_migrat = (migrat_5==1 & dist_migrat==1)
			gen dist_10_migrat = (migrat_10==1 & dist_migrat==1)
		keep y5_hhid indidy5 migrate migrat_10 migrat_5 dist_migrat reg_migrat reg_5_migrat reg_10_migrat ///
			 dist_5_migrat dist_10_migrat
			foreach var of varlist dist_migrat reg_migrat reg_5_migrat reg_10_migrat dist_5_migrat dist_10_migrat {
				replace `var' = 0 if `var' == .
			}

			label var migrate "Name was not born in born in current location"
			label var migrat_5 "Migrated to current location within the last 5 years"
			label var migrat_10 "Migrated to current location within the last 10 years"
			label var dist_migrat "Inter-district migration - Name migrated from another district"
			label var reg_migrat "Inter-region migration - Name migrated from another region"
			label var dist_5_migrat "Inter-district migration within last 5 years"
			label var dist_10_migrat "Inter-district migration within last 10 years"
			label var reg_5_migrat "Inter-region migration within last 5 years"
			label var reg_10_migrat "Inter-region migration within last 10 years"
			
			foreach var of varlist migrate migrat_10 migrat_5 dist_migrat reg_migrat reg_5_migrat reg_10_migrat ///
			 dist_5_migrat dist_10_migrat {
			 	rename `var' y5_`var'
			 }
			 
			 tempfile migration
			save `migration', replace
		mmerge y5_hhid indidy5 using `w5_indiv'
		save `w5_indiv', replace
					
	//	WAVE 5	- Labor	
		use "$y5data\hh_sec_e1.dta", clear
		mmerge y5_hhid indidy5 using"$y5data\hh_sec_e2.dta"
		mmerge y5_hhid using "$y5data\hh_sec_a.dta", ukeep(y4_hhid) 
			
		//	Type of employment
			gen wage_y5    = hh_e03==1 | hh_e11==1
			gen selfemp_y5 = (hh_e05==1 | hh_e06a==1)
			gen agric_y5   = hh_e07==1
			label var wage_y5    "Wage employment in Wave 5"
			label var selfemp_y5 "Self-employed non-agriculture in Wave 5"
			label var agric_y5   "Agriculture in Wave 5"	
			
		//	Employed
		*	gen employed = (wage==1 | selfemp==1 | (agric==1 & inlist(hh_e09,1,2)))
			gen employed_y5 = (wage_y5==1 | selfemp_y5==1 | agric_y5==1)
						
		//	Type of Employment - Last 12 Months
			gen wage12_y5    = (hh_e203==1 | hh_e206==1)
			gen selfemp12_y5 = hh_e204==1
			gen agric12_y5   = hh_e205==1
			recode wage12_y5 selfemp12_y5 agric12_y5 (1=100)
			label var wage12_y5    "Wage employment (last 12 months)"
			label var selfemp12_y5 "Self-employed non-agriculture (last 12 months)"
			label var agric12_y5   "Agriculture (last 12 months)"

		//	Income Diversification
			gen wage_only_y5  = (hh_e203==1 & hh_e204==2 & hh_e205==2)
			gen self_only_y5  = (hh_e203==2 & hh_e204==1 & hh_e205==2)
			gen agr_only_y5   = (hh_e203==2 & hh_e204==2 & hh_e205==1)
			gen wage_self_y5  = (hh_e203==1 & hh_e204==1 & hh_e205==2)
			gen agr_self_y5   = (hh_e203==2 & hh_e204==1 & hh_e205==1)
			gen wage_agr_y5   = (hh_e203==1 & hh_e204==2 & hh_e205==1)
			gen all3source_y5 = (hh_e203==1 & hh_e204==1 & hh_e205==1)

			foreach var of varlist *only_* wage_self_y5 wage_agr_y5 agr_self_y5 all3source_y5 {
				recode `var' (1=100)
		}
		
		//	Wage Sector
			gen sector_wage_y5 = .
			replace sector_wage_y5 = 1 if inrange(hh_e31b_4,111,321)
			replace sector_wage_y5 = 2 if inrange(hh_e31b_4,510,4390)
			replace sector_wage_y5 = 3 if inrange(hh_e31b_4,4510,9900) 
			tab sector_wage_y5
				
				lab def sector_wage_y5 1 "Agriculture" 2 "Industry, including manufacturing" 3 "Services - both market and non-market"
				lab val sector_wage_y5 sector_wage_y5
				numlabel, add		
			
			tempfile y5_employed
			save `y5_employed'
			
		//	Non-Farm Enterprise Workers
			use "$y5data\hh_sec_n.dta", clear
				gen sector_nfe_y5 = .
				replace sector_nfe_y5 = 1 if inlist(hh_n02_3,1,2,3)
				replace sector_nfe_y5 = 2 if inrange(hh_n02_3,5,43) | inrange(hh_n02_3,101,107)
				replace sector_nfe_y5 = 3 if inrange(hh_n02_3,45,99) | inrange(hh_n02_3,471,479) | inrange(hh_n02_3,4921,4923) | inrange(hh_n02_3,491,493) | inrange(hh_n02_3,561,563)
				tab sector_nfe_y5
					
				lab def sector_nfe_y5 1 "Agriculture" 2 "Industry, including manufacturing" 3 "Services - both market and non-market"
				lab val sector_nfe_y5 sector_nfe_y5
				numlabel, add
				
		keep y5_hhid enterprise_id hh_n03_1 hh_n03_2 hh_n03_3 hh_n03_4 hh_n03_5 hh_n03_6 sector_nfe_y5
		drop if enterprise_id==.
		preserve
			keep y5_hhid enterprise_id hh_n03_1 sector_nfe_y5
			drop if hh_n03_1==.
			rename hh_n03_1 indidy5
				tempfile first_person
				save `first_person'
			*reshape long sector_nfe_y5 i(y5_hhid) j(hh_n03)
		restore
				
		preserve
			keep y5_hhid enterprise_id hh_n03_2 sector_nfe_y5
			drop if hh_n03_2==.
			rename hh_n03_2 indidy5
				tempfile second_person
				save `second_person'
		restore	

		preserve
			keep y5_hhid enterprise_id hh_n03_3 sector_nfe_y5
			drop if hh_n03_3==.
			rename hh_n03_3 indidy5
				tempfile third_person
				save `third_person'
		restore	
		preserve
			keep y5_hhid enterprise_id hh_n03_4 sector_nfe_y5
			drop if hh_n03_4==.
			rename hh_n03_4 indidy5
				tempfile fourth_person
				save `fourth_person'
		restore	
		
		preserve
			keep y5_hhid enterprise_id hh_n03_5 sector_nfe_y5
			drop if hh_n03_5==.
			rename hh_n03_5 indidy5
				tempfile fifth_person
				save `fifth_person'
		restore	
		
		preserve
			keep y5_hhid enterprise_id hh_n03_6 sector_nfe_y5
			drop if hh_n03_6==.
			rename hh_n03_6 indidy5
				tempfile sixth_person
				save `sixth_person'
		restore	
		
		use `first_person', clear
		append using `second_person'
		append using `third_person'
		append using `fourth_person'
		append using `fifth_person'
		append using `sixth_person'
		
	//	Drop Observations where one Person worked in the same Sector of NFE
		duplicates drop y5_hhid indidy5 sector_nfe_y5, force
		
		drop enterprise_id
		tempfile nfe_sector
		save `nfe_sector', replace
		
	//	Merge with the Employment Data
		mmerge y5_hhid indidy5 using `y5_employed'
		
	//	Now Generate the Sector Variable for Y5
		gen sector_y5 = sector_wage_y5
		replace sector_y5 = sector_nfe_y5 if sector_wage_y5==. & sector_nfe_y5!=. & selfemp_y5==1
		replace sector_y5 = 1 if sector_y5==. & agric_y5== 1 
		
	//	Keep Relevant Variables
		keep y5_hhid y4_hhid indidy5 wage_y5 selfemp_y5 agric_y5 employed_y5 wage12_y5 selfemp12_y5 agric12_y5 wage_only_y5 ///
			 self_only_y5 agr_only_y5 wage_self_y5 agr_self_y5 wage_agr_y5 all3source_y5 sector_y5 
		
			tempfile wave_5_Sector
			save `wave_5_Sector', replace
			
	//	Merge with the Y5 HH and Individual Level Data
		mmerge y5_hhid indidy5 using `w5_indiv'
			keep if _m==3

	//	Generate Employment Shares
		preserve
			keep y5_hhid y4_hhid cluster sector_y5 
			tab sector_y5, gen(shares)
			rename shares1 agr_share_y5
			rename shares2 ind_share_y5
			rename shares3 ser_share_y5
			
				foreach var of varlist agr_share_y5 ind_share_y5 ser_share_y5 {
				replace `var'=`var'*100
				}		
				
			collapse (mean) agr_share_y5 ind_share_y5 ser_share_y5, by(cluster)
			tempfile y5_emp_shares
			save `y5_emp_shares', replace
		restore
		
		mmerge cluster using `y5_emp_shares'
		save `w5_indiv', replace	
		
	
****************************** WAVE 4 ADDITIONAL DATA PREPARATION ****************************************

	//	Basic Variables 
		use "$output\basicvars_y4", clear 
		tempfile w4_basicvars
		save `w4_basicvars', replace		
		
	//	Bring the Consumption and Poverty Variables 
		use "$y5data\consumption_real_y4", clear 
			foreach var of varlist femalehead - expmR_pae {
				rename `var' y4_`var'
		}
		mmerge y4_hhid using `w4_basicvars'

		save `w4_basicvars', replace				

	//	Bring in the Housing Variables
		use "$output\housing_y4", clear
		foreach var of varlist roof floor walls basicsanit - electricity {
			rename `var' y4_`var'
		}
		mmerge y4_hhid using `w4_basicvars'
		
		save `w4_basicvars', replace		
		
	//	Bring in the Food Security Variables
		use "$output\food_security", clear
		keep if round == 4
		foreach var of varlist diet_diversity {
			rename `var' y4_`var'
		}
		mmerge y4_hhid using `w4_basicvars'
		
		save `w4_basicvars', replace
		
	//	Call the Household Roster 
		use "$y4data\hh_sec_b", clear	
	
		gen sex_y4 = hh_b02
			recode sex (1=0 )
			recode sex (2=1 )
		gen age_y4 = hh_b04
		summ sex_y4 age
		tab1 sex_y4 age_y4, m
		
		gen married_y4 = inlist(hh_b19,1,2,3)
		gen h_age = age if hh_b05==1
		bysort y4_hhid: egen head_age_y4 = max(h_age)
		gen h_married = married if hh_b05==1
		bysort y4_hhid: egen head_married_y4 = max(h_married)
		
		gen youth = inrange(age,15,30)
		
		gen youth_y4 = inrange(age,15,30)				
		
		keep y4_hhid indidy4 sex_y4 age_y4 married_y4 youth_y4 head_age_y4 head_married_y4
		mmerge y4_hhid using `w4_basicvars'
		sort y4_hhid indidy4
		 tempfile w4_indiv
		 save `w4_indiv', replace		
		
	//	Call the Education Variable
		use "$y4data\hh_sec_c", clear	
		mmerge y4_hhid indidy4 using "$y4data\hh_sec_b"

		gen attending_y4 = hh_c05==1
		tab attending_y4, m

		gen level_y4 = 9
		replace level_y4 = 1 if hh_c07==1
		replace level_y4 = 2 if inrange(hh_c07,11,17)
		replace level_y4 = 3 if inrange(hh_c07,21,24)
		replace level_y4 = 4 if inrange(hh_c07,41,45)
		label define level_y4 1 Preprimary 2 Primary 3 Secondary 4 Uni 9 Other
		
		gen primary_y4 = level_y4 == 2
		gen secondary_y4 = level_y4 == 3
		gen tertiary_y4 = level_y4 == 4
		gen secondary_plus_y4 = (secondary_y4==1 | tertiary_y4==1)
		
		gen h_pri_edu = primary_y4 if hh_b05==1
		gen h_sec_edu = secondary_y4 if hh_b05==1
		gen h_sec_plus_edu = secondary_plus_y4 if hh_b05==1
		gen h_ter_edu = tertiary if hh_b05==1
		bysort y4_hhid: egen head_pri_edu_y4 = max(h_pri_edu)
		bysort y4_hhid: egen head_sec_edu_y4 = max(h_sec_edu)
		bysort y4_hhid: egen head_sec_plus_edu_y4 = max(h_sec_plus_edu)
		bysort y4_hhid: egen head_ter_edu_y4 = max(h_ter_edu)
		
					 		
		keep y4_hhid indidy4 attending_y4 level_y4 primary_y4 secondary_y4 tertiary_y4 secondary_plus_y4 ///
			 head_pri_edu_y4 head_sec_edu_y4 head_sec_plus_edu_y4 head_ter_edu_y4
		
		mmerge y4_hhid indidy4 using `w4_indiv'
		sort y4_hhid indidy4
		save `w4_indiv', replace	
		
	//	Migration 
		use "$y4data\hh_sec_b.dta" , clear
			gen migrate = (hh_b26<99) & hh_b26!=.
			gen migrat_10 = inrange(hh_b26,0,10)
			gen migrat_5 = inrange(hh_b26,0,5)
		mmerge y4_hhid using "$y4data\hh_sec_a.dta" 
			gen dist_migrat = (hh_b27_3!=hh_a02_1) if migrate==1
			gen reg_migrat = (hh_b27_2!=hh_a01_1) if migrate==1
			gen reg_5_migrat = (migrat_5==1 & reg_migrat==1) 
			gen reg_10_migrat = (migrat_10==1 & reg_migrat==1)
			gen dist_5_migrat = (migrat_5==1 & dist_migrat==1)
			gen dist_10_migrat = (migrat_10==1 & dist_migrat==1)
		keep y4_hhid indidy4 migrate migrat_10 migrat_5 dist_migrat reg_migrat reg_5_migrat reg_10_migrat ///
			 dist_5_migrat dist_10_migrat
			foreach var of varlist dist_migrat reg_migrat reg_5_migrat reg_10_migrat dist_5_migrat dist_10_migrat {
				replace `var' = 0 if `var' == .
			}

			label var migrate "Name was not born in born in current location"
			label var migrat_5 "Migrated to current location within the last 5 years"
			label var migrat_10 "Migrated to current location within the last 10 years"
			label var dist_migrat "Inter-district migration - Name migrated from another district"
			label var reg_migrat "Inter-region migration - Name migrated from another region"
			label var dist_5_migrat "Inter-district migration within last 5 years"
			label var dist_10_migrat "Inter-district migration within last 10 years"
			label var reg_5_migrat "Inter-region migration within last 5 years"
			label var reg_10_migrat "Inter-region migration within last 10 years"
			
			foreach var of varlist migrate migrat_10 migrat_5 dist_migrat reg_migrat reg_5_migrat reg_10_migrat ///
			 dist_5_migrat dist_10_migrat {
			 	rename `var' y4_`var'
			 }
			 
			 tempfile migration
			save `migration', replace
		mmerge y4_hhid indidy4 using `w4_indiv'
		save `w4_indiv', replace
		
	//	WAVE 4 - Labor		
		use "$y4data\hh_sec_e.dta", clear
		
		//	Type of employment - Last 7 Days
			gen wage_y4= hh_e08ab==1 
			gen selfemp_y4 = hh_e08cd ==1
			gen agric_y4   = hh_e08e==1
			label var wage_y4    "Wage employment"
			label var selfemp_y4 "Self-employed non-agriculture"
			label var agric_y4   "Agriculture"	
			
		//	Employed
			gen employed_y4 = (wage_y4==1 | selfemp_y4==1 | agric_y4==1 )

		//	Type of Employment - Last 12 Months
			gen wage12_y4    = hh_e04ab==1
			gen selfemp12_y4 = hh_e04cd==1
			gen agric12_y4   = hh_e04e==1
			recode wage12_y4 selfemp12_y4 agric12_y4 (1=100)
			label var wage12_y4    "Wage employment (last 12 months)"
			label var selfemp12_y4 "Self-employed non-agriculture (last 12 months)"
			label var agric12_y4   "Agriculture (last 12 months)"

		//	Income Diversification
			gen wage_only_y4 = (hh_e04ab==1 & hh_e04cd==2 & hh_e04e==2)
			gen self_only_y4 = (hh_e04ab==2 & hh_e04cd==1 & hh_e04e==2)
			gen agr_only_y4 = (hh_e04ab==2 & hh_e04cd==2 & hh_e04e==1)
			gen wage_self_y4 = (hh_e04ab==1 & hh_e04cd==1 & hh_e04e==2)
			gen agr_self_y4 = (hh_e04ab==2 & hh_e04cd==1 & hh_e04e==1)
			gen wage_agr_y4   = (hh_e04ab==1 & hh_e04cd==2 & hh_e04e==1)
			gen all3source_y4 = (hh_e04ab==1 & hh_e04cd==1 & hh_e04e==1)

			foreach var of varlist *only_* wage_self wage_agr agr_self all3source_y4 {
				recode `var' (1=100)
		}
		
		//	Wage Sector 
			gen sector_wage_y4 = .
			replace sector_wage_y4 = 1 if inlist(hh_e21_2,1,2,3)
			replace sector_wage_y4 = 2 if inrange(hh_e21_2,5,43) | inrange(hh_e21_2,101,107)
			replace sector_wage_y4 = 3 if inrange(hh_e21_2,45,99) | inrange(hh_e21_2,471,479) | inrange(hh_e21_2,4921,4923) | inrange(hh_e21_2,491,493) | inrange(hh_e21_2,561,563)
			tab sector_wage_y4
		
		lab def sector_wage_y4 1 "Agriculture" 2 "Industry, including manufacturing" 3 "Services - both market and non-market"
		lab val sector_wage_y4 sector_wage_y4
		numlabel, add	
			
			tempfile y4_employed
			save `y4_employed'		
		
	//	Wave 4 NFE - Those that Worked in NFE
			use "$y4data\hh_sec_n.dta", clear
			gen sector_nfe_y4 = .
			replace sector_nfe_y4 = 1 if inlist(hh_n02_3,1,2,3)
			replace sector_nfe_y4 = 2 if inrange(hh_n02_3,5,43) | inrange(hh_n02_3,101,107)
			replace sector_nfe_y4 = 3 if inrange(hh_n02_3,45,99) | inrange(hh_n02_3,471,479) | inrange(hh_n02_3,4921,4923) | inrange(hh_n02_3,491,493) | inrange(hh_n02_3,561,563)
			tab sector_nfe_y4
				
				lab def sector_nfe_y4 1 "Agriculture" 2 "Industry, including manufacturing" 3 "Services - both market and non-market"
				lab val sector_nfe_y4 sector_nfe_y4
				numlabel, add		
		
		keep y4_hhid entid hh_n03_1 hh_n03_2 hh_n03_3 hh_n03_4 hh_n03_5 hh_n03_6 sector_nfe_y4
		drop if entid==.
		preserve
			keep y4_hhid entid hh_n03_1 sector_nfe_y4
			drop if hh_n03_1==.
			rename hh_n03_1 indidy4
				tempfile first_person
				save `first_person'
			*reshape long sector_nfe_y5 i(y5_hhid) j(hh_n03)
		restore
				
		preserve
			keep y4_hhid entid hh_n03_2 sector_nfe_y4
			drop if hh_n03_2==.
			rename hh_n03_2 indidy4
				tempfile second_person
				save `second_person'
		restore	

		preserve
			keep y4_hhid entid hh_n03_3 sector_nfe_y4
			drop if hh_n03_3==.
			rename hh_n03_3 indidy4
				tempfile third_person
				save `third_person'
		restore	
		preserve
			keep y4_hhid entid hh_n03_4 sector_nfe_y4
			drop if hh_n03_4==.
			rename hh_n03_4 indidy4
				tempfile fourth_person
				save `fourth_person'
		restore	
		
		preserve
			keep y4_hhid entid hh_n03_5 sector_nfe_y4
			drop if hh_n03_5==.
			rename hh_n03_ indidy5
				tempfile fifth_person
				save `fifth_person'
		restore	
		
		preserve
			keep y4_hhid entid hh_n03_6 sector_nfe_y4
			drop if hh_n03_6==.
			rename hh_n03_6 indidy5
				tempfile sixth_person
				save `sixth_person'
		restore	
		
		use `first_person', clear
		append using `second_person'
		append using `third_person'
		append using `fourth_person'
		append using `fifth_person'
		append using `sixth_person'
		
	//	Drop Observations where one Person worked in the same Sector of NFE
		duplicates drop y4_hhid indidy4 sector_nfe_y4, force
		
		drop entid
		tempfile nfe_sector_y4
		save `nfe_sector_y4', replace
		
	//	Merge with the Employment Data
		mmerge y4_hhid indidy4 using `y4_employed'
		
	//	Now Generate the Sector Variable for Y4
		gen sector_y4 = sector_wage_y4
		replace sector_y4 = sector_nfe_y4 if sector_wage_y4==. & sector_nfe_y4!=. & selfemp_y4==1
		replace sector_y4 = 1 if sector_y4==. & agric_y4== 1 
		
	//	Keep Relevant Variables
		keep y4_hhid indidy4 wage_y4 selfemp_y4 agric_y4 employed_y4 wage12 selfemp12 agric12 wage_only_y4 self_only_y4 ///
			 agr_only_y4 wage_self_y4 agr_self_y4 wage_agr_y4 all3source_y4 sector_y4 
		
			tempfile wave_4_Sector
		save `wave_4_Sector', replace	
		
	//	Merge with the Y4 HH and Individual Level Data
		mmerge y4_hhid indidy4 using `w4_indiv'
			keep if _m==3
			
	//	Generate Employment Shares
		preserve
			keep y4_hhid cluster sector_y4 
			tab sector_y4, gen(shares)
			rename shares1 agr_share_y4
			rename shares2 ind_share_y4
			rename shares3 ser_share_y4
			
				foreach var of varlist agr_share_y4 ind_share_y4 ser_share_y4 {
				replace `var'=`var'*100
				}		
				
			collapse (mean) agr_share_y4 ind_share_y4 ser_share_y4, by(cluster)
			tempfile y4_emp_shares
			save `y4_emp_shares', replace
		restore
		
		mmerge cluster using `y4_emp_shares'
		
		save `w4_indiv', replace
		
	
************************ COMBINE Y4 & Y5, GENERATE ADDITIONAL VARIABLES, AND SAVE ANALYTICAL DATAFILE *********************
			
	//	 Combine Y4 & Y5 Sectors
		use `w5_indiv', clear
		*rename indidy5  indidy4
		rename hh_b06  indidy4
		mmerge y4_hhid indidy4 using `w4_indiv'
		keep if _m==3
			
	//	Sectoral Transitions
	
		//	Agriculture Transition
			gen agr_agr = 1 if sector_y4==1 & sector_y5==1
				replace agr_agr = 0 if sector_y4==1 & sector_y5 != 1
			gen agr_ind = 1 if sector_y4==1 & sector_y5==2
				replace agr_ind = 0 if sector_y4==1 & sector_y5 == 1
			gen agr_ser = 1 if sector_y4==1 & sector_y5==3
				replace agr_ser = 0 if sector_y4==1 & sector_y5 == 1		
	
		//	Industry Transition
			gen ind_agr = 1 if sector_y4==2 & sector_y5==1
				replace ind_agr = 0 if sector_y4==2 & sector_y5 == 3
			gen ind_ind = 1 if sector_y4==2 & sector_y5==2
				replace ind_ind = 0 if sector_y4==2 & sector_y5 != 2
			gen ind_ser = 1 if sector_y4==2 & sector_y5==3
				replace ind_ser = 0 if sector_y4==2 & sector_y5 == 2						
		
		//	Service Transition
			gen ser_agr = 1 if sector_y4==3 & sector_y5==1
				replace ser_agr = 0 if sector_y4==3 & sector_y5 == 3
			gen ser_ind = 1 if sector_y4==3 & sector_y5==2
				replace ser_ind = 0 if sector_y4==3 & sector_y5 == 3
			gen ser_ser = 1 if sector_y4==3 & sector_y5==3
				replace ser_ser = 0 if sector_y4==3 & sector_y5 != 3			

//	NOW KEEP ONLY OBSERVATIONS THAT HAVE SECTOR INFORMATION IN BOTH WAVES		
	keep if sector_y4 != . & sector_y5!=.
	
		
	//	CPI and PPP for Poverty Line
	
		gen cpi2015_wdi = 158.021 //Survey country CPI for year 2015								
		gen cpi2017_wdi = 175.038 //Survey country CPI of the year and month of the survey 				
		gen cpi2021_wdi = 200.743 //Survey country CPI for year 2021, in 2010 constant prices 									
		gen ppp2015_wdi = 727.542 //Survey country 2015 PPP conversion factor, private consumption	
		gen ppp2017_wdi = 754.622 //Survey country 2017 PPP conversion factor, private consumption	
		gen ppp2021_wdi = 782.878 //Survey country 2021 PPP conversion factor, private consumption	
	
		//	Express everything in 2017 Constant prices 
			gen defla2015 = cpi2015_wdi / cpi2021_wdi
			gen defla2021 = cpi2021_wdi / cpi2021_wdi
 		
			gen y4_cons_exp_pae = y4_expmR_pae / defla2015
			gen y5_cons_exp_pae = y5_expmR_pae / defla2021
		
			gen povline215_LCU	 = (2.15 * 28 * ppp2017_wdi) * (cpi2021_wdi/cpi2017_wdi)

			**Create a variable that flags households that have a consumption aggregate 
			**    below the USD $2.15 poverty line at 2017 PPP converted to local currency.
				
			gen y4_poor = 0
			replace y4_poor = 1 if (y4_cons_exp_pae < povline215_LCU) 
			gen y5_poor = 0
			replace y5_poor = 1 if (y5_cons_exp_pae < povline215_LCU) 

			*gen y4_gap =((povline215_LCU - y4_cons_exp_pae) / povline215_LCU) * 100
			gen y4_gap = (y4_poor*((povline215_LCU - y4_cons_exp_pae)/povline215_LCU)^1)
			gen y4_gap2 = (y4_poor*((povline215_LCU - y4_cons_exp_pae)/povline215_LCU)^2)

			gen y5_gap = (y5_poor*((povline215_LCU - y5_cons_exp_pae)/povline215_LCU)^1)
			gen y5_gap2 = (y5_poor*((povline215_LCU - y5_cons_exp_pae)/povline215_LCU)^2)

		//	Poverty Transitions 
			gen poor_poor  	= y4_poor ==1 & y5_poor==1
			gen poor_npoor	= y4_poor ==1 & y5_poor==0
			gen npoor_poor 	= y4_poor == 0 	& y5_poor==1
			gen npoor_npoor = y4_poor == 0 	& y5_poor==0
			
			gen pos_trans = .
			replace pos_trans = 0 if poor_poor == 1
			replace pos_trans = 1 if poor_npoor==1
			
			gen neg_trans = .
			replace neg_trans = 0 if npoor_npoor == 1
			replace neg_trans = 1 if npoor_poor==1		
			
		gen rural = (urban==1)
	
		gen ln_expmR = ln(y5_cons_exp_pae)		
		global divid_100  y4_electricity y4_basicsanit y4_improved_toilet y4_safewaterrainy y4_improved_rainy y4_safewaterdry ///
				  y4_improved_dry y4_altfuel2 ///
				  y5_electricity y5_basicsanit y5_improved_toilet y5_safewaterrainy y5_improved_rainy y5_safewaterdry ///
				  y5_improved_dry y5_altfuel2 
			foreach var of varlist $divid_100 {
				replace `var' = `var'/100
			}			   
				  
		//	First Tercile Transition
			xtile y4_tercile = y4_cons_exp_pae, nq(3)
			xtile y5_tercile = y5_cons_exp_pae, nq(3)
			
			gen ter1_ter1 = 1 if y4_tercile==1 & y5_tercile==1
				replace ter1_ter1 = 0 if y4_tercile==1 & y5_tercile != 1
			gen ter1_ter2 = 1 if y4_tercile==1 & y5_tercile==2
				replace ter1_ter2 = 0 if y4_tercile==1 & y5_tercile == 1
			gen ter1_ter3 = 1 if y4_tercile==1 & y5_tercile==3
				replace ter1_ter3 = 0 if y4_tercile==1 & y5_tercile == 1 		
	
		//	Second Tercile Transition
			gen ter2_ter1 = 1 if y4_tercile==2 & y5_tercile==1
				replace ter2_ter1 = 0 if y4_tercile==2 & y5_tercile == 2
			gen ter2_ter2 = 1 if y4_tercile==2 & y5_tercile==2
				replace ter2_ter2 = 0 if y4_tercile==2 & y5_tercile != 2
			gen ter2_ter3 = 1 if y4_tercile==2 & y5_tercile==3
				replace ter2_ter3 = 0 if y4_tercile==2 & y5_tercile == 2 					
		
		//	Third Tercile Transition
			gen ter3_ter1 = 1 if y4_tercile==3 & y5_tercile==1
				replace ter3_ter1 = 0 if y4_tercile==3 & y5_tercile == 3
			gen ter3_ter2 = 1 if y4_tercile==3 & y5_tercile==2
				replace ter3_ter2 = 0 if y4_tercile==3 & y5_tercile == 3
			gen ter3_ter3 = 1 if y4_tercile==3 & y5_tercile==3
				replace ter3_ter3 = 0 if y4_tercile==3 & y5_tercile != 3				
							  
	//	Save Analytical Data
		saveold "$output\Tanzania Structural Transformation Paper.dta", replace

	
		
		