**************************************************************
*****	Structural Change and Welfare - WB PRWP Series	******
*****	Before Running this Dofile, please ensure all the ****
*****		Data Preparatory Dofiles have be Implemented *****
****************** TABLES ************************************

	//	Call Analytical Data 
		use "$output\Tanzania Structural Transformation Paper.dta", clear
		
	//	Setup Globals 
		global y4_pov  y4_poor y4_gap y4_gap2 
		global y5_pov  y5_poor y5_gap y5_gap2 
		global indiv   sex_y4 age_y4 primary_y4 secondary_plus_y4 married_y4 /*youth_y4*/ y4_dist_5_migrat y5_reg_5_migrat
		global s_trans agr_agr agr_ind agr_ser ind_agr ind_ind ind_ser ser_agr ser_ind ser_ser
		global w_trans pos_trans neg_trans 
		global shares  agr_share_y5 ind_share_y5 ser_share_y5
		global hhlevel y5_cons_exp_pae ln_expmR y5_diet_diversity y4_hhsize y4_electricity y4_basicsanit y4_safewaterdry ///
					   y4_walls y4_floor y4_roof rural

	//	Table 1: Variable definition and descriptive statistics
			clear matrix
				foreach var of varlist $indiv $s_trans $shares y5_poor $w_trans {
					qui sum `var'  [aw=hhweight]
					mat def Q1 = r(mean)
					mat def Q2 = r(sd)
					*mat def Q3 = r(N)
					matrix rown Q1 = "`var'"
					mat `var' = nullmat(`var'),(Q1),(Q2)
					mat Table1a = nullmat(Table1a)\(`var')
					}
					matlist Table1a
				putexcel set "$tables\Tables - Tanzania Structural Transformation", sheet("Table1 - Variables Definition") mod
				putexcel D4=matrix(Table1a)	
				
			preserve
			duplicates drop y4_hhid, force
				clear matrix
					foreach var of varlist $hhlevel {
						qui sum `var' [aw=hhweight]
						mat def Q1 = r(mean)
						mat def Q2 = r(sd)
						*mat def Q3 = r(N)
						matrix rown Q1 = "`var'"
						mat `var' = nullmat(`var'),(Q1),(Q2)
						mat Table1b = nullmat(Table1b)\(`var')
						}
						matlist Table1b
						
					putexcel set "$tables\Tables - Tanzania Structural Transformation", sheet("Table1 - Variables Definition") mod
					putexcel D26=matrix(Table1b)
			restore		
		
	//	Table 2: Transitions in Sector of Employment between 2015 and 2021 (Y4 and Y5)
		** First Block
			tab sector_y4 sector_y5 [aw=hhweight], row nofreq
		** Second Block
			tab sector_y4 sector_y5 [aw=hhweight], nofreq cell
					
	//	Table 3: Overall poverty/welfare indicators in 2015 and 2021
			preserve
			duplicates drop y4_hhid, force
				clear matrix
					foreach var of varlist y4_cons_exp_pae y4_diet_diversity {
						qui sum `var' [aw=hhweight]
						mat def Q1 = r(mean)
						*mat def Q2 = r(sd)
						*mat def Q3 = r(N)
						matrix rown Q1 = "`var'"
						mat `var' = nullmat(`var'),(Q1)
						mat Table3a = nullmat(Table3a)\(`var')
						}
						matlist Table3a
						
					putexcel set "$tables\Tables - Tanzania Structural Transformation", sheet("Table 3 - Overall Welfare Indi ") mod
					putexcel D4=matrix(Table3a[1..1,1...])
					putexcel D8=matrix(Table3a[2..2,1...])
					
				clear matrix
					foreach var of varlist y5_cons_exp_pae y5_diet_diversity {
						qui sum `var' [aw=hhweight]
						mat def Q1 = r(mean)
						*mat def Q2 = r(sd)
						*mat def Q3 = r(N)
						matrix rown Q1 = "`var'"
						mat `var' = nullmat(`var'),(Q1)
						mat Table3b = nullmat(Table3b)\(`var')
						}
						matlist Table3b
						
					putexcel set "$tables\Tables - Tanzania Structural Transformation", sheet("Table 3 - Overall Welfare Indi ") mod
					putexcel E4=matrix(Table3b[1..1,1...])
					putexcel E8=matrix(Table3b[2..2,1...])
					
				clear matrix
					foreach var of varlist $y4_pov {
						qui sum `var' [aw=hhweight*y4_hhsize]
						mat def Q1 = r(mean)
						*mat def Q2 = r(sd)
						*mat def Q3 = r(N)
						matrix rown Q1 = "`var'"
						mat `var' = nullmat(`var'),(Q1)
						mat Table3c = nullmat(Table3c)\(`var')
						}
						matlist Table3c
						
					putexcel set "$tables\Tables - Tanzania Structural Transformation", sheet("Table 3 - Overall Welfare Indi ") mod
					putexcel D5=matrix(Table3c)

				clear matrix
					foreach var of varlist $y5_pov {
						qui sum `var' [aw=hhweight*y5_hhsize]
						mat def Q1 = r(mean)
						*mat def Q2 = r(sd)
						*mat def Q3 = r(N)
						matrix rown Q1 = "`var'"
						mat `var' = nullmat(`var'),(Q1)
						mat Table3d = nullmat(Table3d)\(`var')
						}
						matlist Table3d
						
					putexcel set "$tables\Tables - Tanzania Structural Transformation", sheet("Table 3 - Overall Welfare Indi ") mod
					putexcel E5=matrix(Table3d)
					
				restore	
	
	//	Table 4: Transitions in poverty status between 2015 and 2021 (Y4 and Y5)			
			** First Block
				tab y4_poor y5_poor [aw=hhweight], row nofreq
			** Second Block
				tab y4_poor y5_poor [aw=hhweight], nofreq cell 
					
	//	Figure 3: The welfare quadrants – a scatter diagram depicting transitions in welfare, 2015 – 2021 
		preserve 
			winsor y4_cons_exp_pae, gen(w_y4_expmR_pae) p(0.01) highonly
			winsor y5_cons_exp_pae, gen(w_y5_expmR_pae) p(0.01) highonly

			graph twoway (scatter w_y4_expmR_pae w_y5_expmR_pae, ms(o) msize(tiny) mcolor(green) lpattern(solid) ///
			 lwidth(thick) lcolor(red) yline(52099.56, lwidth(thick) lcolor(red)) xline(52099.56, lwidth(thick) lcolor(brown)))
			 graph save "$tables\Scatter plots.gph", replace
		restore
		
	//	Figure 4: Changes in consumption expenditure by sectoral transitions (%)
		gen change_cons = y5_cons_exp_pae - y4_cons_exp_pae
		gen per_chan_cons = ((y5_cons_exp_pae - y4_cons_exp_pae)/y4_cons_exp_pae) * 100
		gen cons_posit_change = (change_cons>0)*100
		
		clear matrix
			foreach pov of varlist change_cons per_chan_cons cons_posit_change {
				foreach var of varlist agr_agr agr_ind agr_ser ind_agr ind_ind ind_ser ser_agr ser_ind ser_ser {
					sum `pov' if `var' ==1
					matrix Q1 = r(mean)
					matrix rown Q1 = "`var'"
					mat `var'`pov' = nullmat(`var'`pov'),(Q1)
					mat Table7=nullmat(Table7)\(`var'`pov')	
					}
					matlist Table7							
				}
							
					matlist Table7
					mat A = Table7[1..9,1..1]
					mat B = Table7[10..18,1..1]		
					mat C = Table7[19..27,1..1]		
					*mat D = Table7[28..36,1..1]		
					*mat E = Table7[37..45,1..1]		
			
			putexcel set "$tables\Tables - Tanzania Structural Transformation", sheet("Figure 4 - Consumption Changes") mod
			putexcel B4=matrix(A)
			putexcel C4=matrix(B)		
			putexcel D4=matrix(C)
			*putexcel E4=matrix(D)
			*putexcel F4=matrix(E)
			
	//	Table 5: Poverty indicators at 2021 by specific sectoral labour movements
			clear matrix
			foreach pov of varlist y5_cons_exp_pae y5_poor y5_gap y5_gap2 y5_diet_diversity {
				foreach var of varlist agr_agr agr_ind agr_ser ind_agr ind_ind ind_ser ser_agr ser_ind ser_ser {
					sum `pov' if `var' ==1
					matrix Q1 = r(mean)
					matrix rown Q1 = "`var'"
					mat `var'`pov' = nullmat(`var'`pov'),(Q1)
					mat Table6=nullmat(Table6)\(`var'`pov')	
					}
					matlist Table6							
				}
				
					matlist Table6
					mat A = Table6[1..9,1..1]
					mat B = Table6[10..18,1..1]		
					mat C = Table6[19..27,1..1]		
					mat D = Table6[28..36,1..1]		
					mat E = Table6[37..45,1..1]		
			
			putexcel set "$tables\Tables - Tanzania Structural Transformation", sheet("Table 5 - Pov and Lab Trans") mod
			putexcel C4=matrix(A)
			putexcel D4=matrix(B)		
			putexcel E4=matrix(C)
			putexcel F4=matrix(D)
			putexcel G4=matrix(E)
			
			foreach var of varlist agr_agr agr_ind agr_ser ind_agr ind_ind ind_ser ser_agr ser_ind ser_ser {
				egen med_`var' = median(y5_cons_exp_pae) if `var' == 1
			}
			
			foreach var of varlist med_* {
				sum `var' 
				matrix Q1 = r(mean)
					matrix rown Q1 = "`var'"
					mat `var'= nullmat(`var'),(Q1)
					mat Table6a=nullmat(Table6a)\(`var')	
				}
				matlist Table6a
			putexcel set "$tables\Tables - Tanzania Structural Transformation", sheet("Table 5 - Pov and Lab Trans") mod
			putexcel B4=matrix(Table6a)
			
	//	Table 6: Individual Characteristics by specific sectoral labour movements
			clear matrix
			foreach pov of varlist sex_y4 age_y4 primary_y4 secondary_plus_y4 married_y4 youth_y4 y4_dist_5_migrat y5_reg_5_migrat {
				foreach var of varlist agr_agr agr_ind agr_ser ind_agr ind_ind ind_ser ser_agr ser_ind ser_ser {
					sum `pov' if `var' ==1
					matrix Q1 = r(mean)
					matrix rown Q1 = "`var'"
					mat `var'`pov' = nullmat(`var'`pov'),(Q1)
					mat Table5=nullmat(Table5)\(`var'`pov')	
					}
					matlist Table5						
				}				
					matlist Table5
					mat A = Table5[1..9,1..1]*100
					mat B = Table5[10..18,1..1]
					mat C = Table5[19..27,1..1]*100	
					mat D = Table5[28..36,1..1]*100		
					mat E = Table5[37..45,1..1]*100	
					mat F = Table5[46..54,1..1]*100	
					mat G = Table5[55..63,1..1]*100
					mat H = Table5[64..72,1..1]*100
					*mat I = Table5[73..81,1..1]*100
					
			putexcel set "$tables\Tables - Tanzania Structural Transformation", sheet("Table 6 - Y4 Indiv Lab Trans") mod
			putexcel B4=matrix(A)
			putexcel C4=matrix(B)		
			putexcel D4=matrix(C)
			putexcel E4=matrix(D)				
			putexcel F4=matrix(E)				
			putexcel G4=matrix(F)
			putexcel H4=matrix(G)
			putexcel I4=matrix(H)
			*putexcel J4=matrix(I)		
		
	//	Table 7: Effect of cross-sector labour movement on welfare indicators at 2021
				   
		global yvars y5_poor y5_gap pos_trans neg_trans
		global c_yvars ln_expmR y5_diet_diversity
		global xvars sex_y4 age_y4 married_y4 primary_y4 secondary_plus_y4 rural y4_hhsize y5_dist_5_migrat y5_reg_5_migrat ///
					   y4_electricity y4_basicsanit y4_safewaterdry y4_walls y4_floor y4_roof

		**	OLS - Regression 
			reg ln_expmR  $xvars agr_ser, robust
				est store Eqn1
			reg ln_expmR  $xvars agr_ind, robust
				est store Eqn2
			reg ln_expmR  $xvars ind_ser, robust
				est store Eqn3
			reg ln_expmR  $xvars ind_agr, robust
				est store Eqn4				
			reg ln_expmR  $xvars ser_agr, robust
				est store Eqn5
			reg ln_expmR  $xvars ser_ind, robust
				est store Eqn6	
				
		**	Probit - Regression
			probit y5_poor $xvars agr_ser, robust
				est store Eqn7
			probit y5_poor $xvars agr_ind, robust
				est store Eqn8
			probit y5_poor $xvars ind_ser, robust
				est store Eqn9
			probit y5_poor $xvars ind_agr, robust
				est store Eqn10
			probit y5_poor $xvars ser_agr, robust
				est store Eqn11
			probit y5_poor $xvars ser_ind, robust
				est store Eqn12	
				
		outreg2 [Eqn1 Eqn2 Eqn3 Eqn4 Eqn5 Eqn6 Eqn7 Eqn8 Eqn9 Eqn10 Eqn11 Eqn12] using "$tables/Table 7 - Cross-sector transition and welfare 2021.xls", replace symbol(***, **, *) e(N ll r2_p r2 chi2 p F p) dec(4)	
	
	
	//	Table 8: Effect of cross-sector labour movement on welfare transitions - Probit regression results
			probit pos_trans $xvars agr_ser, robust
				est store Eqnt1
			probit pos_trans $xvars agr_ind, robust
				est store Eqnt2
			/*probit pos_trans $xvars ind_ser, robust
				est store Eqn27
			probit pos_trans $xvars ind_agr, robust
				est store Eqn28
			probit pos_trans $xvars ser_agr, robust
				est store Eqn29
			probit pos_trans $xvars ser_ind, robust
				est store Eqn30				
				*/
			probit neg_trans $xvars agr_ser, robust
				est store Eqnt3
			probit neg_trans $xvars agr_ind, robust
				est store Eqnt4
			probit neg_trans $xvars ind_ser, robust
				est store Eqnt5
			probit neg_trans $xvars ind_agr, robust
				est store Eqnt6
			probit neg_trans $xvars ser_agr, robust
				est store Eqnt7
			probit neg_trans $xvars ser_ind, robust
				est store Eqnt8		
				
		outreg2 [Eqnt1 Eqnt2 Eqnt3 Eqnt4 Eqnt5 Eqnt6 Eqnt7 Eqnt8] using "$tables/Table 8 - Probit Cross-sector and welfare transitions.xls", replace symbol(***, **, *) e(N ll r2_p r2 chi2 p F p) dec(4)
		
		
	//	Table 9: Effect of cross-sector labour movement on welfare transitions – IV LIML results
		global x_trans sex_y4 age_y4 married_y4 primary_y4 secondary_plus_y4 rural y4_hhsize y5_dist_5_migrat y5_reg_5_migrat ///
					   y4_electricity y4_basicsanit y4_safewaterdry y4_walls y4_floor y4_roof
					 
		** Positive Transitions
			ivreg2 pos_trans $x_trans (agr_ser = ser_share_y5), liml first endog(agr_ser) savefirst savefprefix(P1) robust 
				est store Equatn1			
			ivreg2 pos_trans $x_trans (agr_ind = ind_share_y5), liml first endog(agr_ind) savefirst savefprefix(P2) robust 
				est store Equatn2		
			
		** Negative Transitions
			ivreg2 neg_trans $x_trans (agr_ser = ser_share_y5), liml first endog(agr_ser) savefirst savefprefix(P3) robust 
				est store Equatn3			
			ivreg2 neg_trans $x_trans (agr_ind = ind_share_y5), liml first endog(agr_ind) savefirst savefprefix(P4) robust 
				est store Equatn4		
			ivreg2 neg_trans $x_trans (ind_ser = ser_share_y5 ind_share_y5), liml first endog(ind_ser) savefirst savefprefix(P18) robust 
				est store Equatn5
			ivreg2 neg_trans $x_trans (ind_agr = agr_share_y5), liml first endog(ind_agr) savefirst savefprefix(P5) robust 
				est store Equatn6		
			ivreg2 neg_trans $x_trans (ser_agr = agr_share_y5 ser_share_y5), liml first endog(ser_agr) savefirst savefprefix(P6) robust 
				est store Equatn7

			ivreg2 neg_trans $x_trans (ser_ind = ser_share_y5 ind_share_y5), liml first endog(ser_ind) savefirst savefprefix(P7) robust 
				est store Equatn8						
			
		outreg2 [Equatn1 Equatn2 Equatn3 Equatn4 Equatn5 Equatn6 Equatn7 Equatn8] using "$tables/Table 9 - IVLIML Cross-sector and welfare transitions.xls", replace symbol(***, **, *) /*e(N ll r2_p r2 chi2 p F p)*/ e(all) dec(4) drop(x_trans)
				
				
	//	Table 10: Determinants of cross-sector labour movements – Probit regression results
		probit agr_ser y4_poor ser_share_y5 agr_share_y5 $x_trans i.strata, robust 
			est store Eqn10_1		
		probit ser_agr y4_poor ser_share_y5 agr_share_y5 $x_trans i.strata, robust 
			est store Eqn10_2		
		probit agr_ind y4_poor ind_share_y5 agr_share_y5 $x_trans i.strata, robust 
			est store Eqn10_3
		probit ind_agr y4_poor agr_share_y5 ind_share_y5 $x_trans i.strata, robust 
			est store Eqn10_4		
		probit ind_ser y4_poor ind_share_y5 ser_share_y5 $x_trans i.strata, robust 
			est store Eqn10_5		
		probit ser_ind y4_poor ind_share_y5 ser_share_y5 $x_trans i.strata, robust 
			est store Eqn10_6	

		outreg2 [Eqn10_1 Eqn10_2 Eqn10_3 Eqn10_4 Eqn10_5 Eqn10_6] using "$tables/Table 10 - Drivers of Cross-sector Transition.xls", ///
			replace symbol(***, **, *) e(N ll r2_p r2 chi2 p F p) dec(4)
			
			
	//	Table 11: Relationship between migration and sectoral transitions 
		global migra_var sex_y4 age_y4 primary_y4 secondary_plus_y4 married_y4 youth_y4 rural y4_hhsize y4_electricity ///
						 y4_basicsanit y4_safewaterdry y4_walls y4_floor y4_roof i.strata 			
		probit y5_dist_5_migrat $migra_var agr_ser, robust
			est store Mig1
		probit y5_dist_5_migrat $migra_var agr_ind, robust
			est store Mig2
		probit y5_dist_5_migrat $migra_var ind_ser, robust
			est store Mig3
		probit y5_dist_5_migrat $migra_var ind_agr, robust
			est store Mig4
		probit y5_dist_5_migrat $migra_var ser_agr, robust
			est store Mig5
		probit y5_dist_5_migrat $migra_var ser_ind, robust
			est store Mig6

		probit y5_reg_5_migrat $migra_var agr_ser, robust
			est store Mig7
		probit y5_reg_5_migrat $migra_var agr_ind, robust
			est store Mig8
		probit y5_reg_5_migrat $migra_var ind_ser, robust
			est store Mig9
		probit y5_reg_5_migrat $migra_var ind_agr, robust
			est store Mig10
		probit y5_reg_5_migrat $migra_var ser_agr, robust
			est store Mig11
		probit y5_reg_5_migrat $migra_var ser_ind, robust
			est store Mig12
			
		outreg2 [Mig1 Mig2 Mig3 Mig4 Mig5 Mig6 Mig7 Mig8 Mig9 Mig10 Mig11 Mig12] using "$tables/Table 11 - Internal Migration and Labor Transition.xls", ///
			replace symbol(***, **, *) e(N ll r2_p r2 chi2 p F p) dec(4) drop($migra_var)
			
			
	//	Table A1: Effect of cross-sector labour movements on dietary diversity at 2021		
			reg y5_diet_diversity $xvars agr_ser, robust
				est store Eqnt1
			reg y5_diet_diversity $xvars agr_ind, robust
				est store Eqnt2
			reg y5_diet_diversity $xvars ind_ser, robust
				est store Eqnt3
			reg y5_diet_diversity $xvars ind_agr, robust
				est store Eqnt4
			reg y5_diet_diversity $xvars ser_agr, robust
				est store Eqnt5
			reg y5_diet_diversity $xvars ser_ind, robust
				est store Eqnt6			
		outreg2 [Eqnt1 Eqnt2 Eqnt3 Eqnt4 Eqnt5 Eqnt6] using "$tables/Table A1 - Labor Transition and Dietary Diversity.xls", ///
			replace symbol(***, **, *) e(N ll r2_p r2 chi2 p F p) dec(4)			

	//	Table A2: Effect of cross-sector labour movement on welfare transitions – IV LIML results
		global x_trans sex_y4 age_y4 married_y4 primary_y4 secondary_plus_y4 rural y4_hhsize y5_dist_5_migrat y5_reg_5_migrat ///
					   y4_electricity y4_basicsanit y4_safewaterdry y4_walls y4_floor y4_roof
					 
		** Positive Transitions
			ivreg2 pos_trans $x_trans (agr_ser = ser_share_y5), liml first endog(agr_ser) savefirst savefprefix(A1) robust 
				est store Equatn1			
			ivreg2 pos_trans $x_trans (agr_ind = ind_share_y5), liml first endog(agr_ind) savefirst savefprefix(A2) robust 
				est store Equatn2		
			
		** Negative Transitions
			ivreg2 neg_trans $x_trans (agr_ser = ser_share_y5), liml first endog(agr_ser) savefirst savefprefix(A3) robust 
				est store Equatn3			
			ivreg2 neg_trans $x_trans (agr_ind = ind_share_y5), liml first endog(agr_ind) savefirst savefprefix(A4) robust 
				est store Equatn4		
			ivreg2 neg_trans $x_trans (ind_ser = ser_share_y5 ind_share_y5), liml first endog(ind_ser) savefirst savefprefix(A5) robust 
				est store Equatn5
			ivreg2 neg_trans $x_trans (ind_agr = agr_share_y5), liml first endog(ind_agr) savefirst savefprefix(A6) robust 
				est store Equatn6		
			ivreg2 neg_trans $x_trans (ser_agr = agr_share_y5 ser_share_y5), liml first endog(ser_agr) savefirst savefprefix(A7) robust 
				est store Equatn7

			ivreg2 neg_trans $x_trans (ser_ind = ser_share_y5 ind_share_y5), liml first endog(ser_ind) savefirst savefprefix(A8) robust 
				est store Equatn8						
			
		outreg2 [Equatn1 Equatn2 Equatn3 Equatn4 Equatn5 Equatn6 Equatn7 Equatn8] using "$tables/Table A2 - IVLIML Cross-sector and welfare transitions - Controls.xls", replace symbol(***, **, *) /*e(N ll r2_p r2 chi2 p F p)*/ e(all) dec(4)	
				
				
	//	Table A3: Impact of initial welfare status on cross-sector labour movements – Probit regression results
		probit agr_ser y4_poor ser_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_1
		probit agr_ser y4_poor ser_share_y5 agr_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_2		
		probit agr_ind y4_poor ind_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_3
		probit agr_ind y4_poor ind_share_y5 agr_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_4
		probit ind_ser y4_poor ser_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_5
		probit ind_ser y4_poor ind_share_y5 ser_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_6		
		probit ind_agr y4_poor agr_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_7
		probit ind_agr y4_poor agr_share_y5 ind_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_8
		probit ser_agr y4_poor agr_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_9
		probit ser_agr y4_poor ser_share_y5 agr_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_10
		probit ser_ind y4_poor ind_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_11
		probit ser_ind y4_poor ind_share_y5 ser_share_y5 $x_trans i.strata, robust 
			est store Eqn7a_12			
		outreg2 [Eqn7a_1 Eqn7a_2 Eqn7a_3 Eqn7a_4 Eqn7a_5 Eqn7a_6 Eqn7a_7 Eqn7a_8 Eqn7a_9 Eqn7a_10 Eqn7a_11 Eqn7a_12] using "$tables/Table A3 - Sectoral Transition and Initial Welfare.xls", replace symbol(***, **, *) e(N ll r2_p r2 chi2 p F p) dec(4)			
		
	//	Table A4: Drivers of internal migration
		global migra_var sex_y4 age_y4 primary_y4 secondary_plus_y4 married_y4 youth_y4 rural y4_hhsize y4_electricity ///
						 y4_basicsanit y4_safewaterdry y4_walls y4_floor y4_roof i.strata 			
		probit y5_dist_5_migrat $migra_var, robust
			est store Mig1
		probit y5_dist_5_migrat $migra_var agr_ser, robust
			est store Mig2		
		probit y5_dist_5_migrat $migra_var agr_ind, robust
			est store Mig3
		probit y5_dist_5_migrat $migra_var ind_ser, robust
			est store Mig4
		probit y5_dist_5_migrat $migra_var ind_agr, robust
			est store Mig5
		probit y5_dist_5_migrat $migra_var ser_agr, robust
			est store Mig6
		probit y5_dist_5_migrat $migra_var ser_ind, robust
			est store Mig7
			
		probit y5_reg_5_migrat $migra_var, robust
			est store Mig8
		probit y5_reg_5_migrat $migra_var agr_ser, robust
			est store Mig9
		probit y5_reg_5_migrat $migra_var agr_ind, robust
			est store Mig10
		probit y5_reg_5_migrat $migra_var ind_ser, robust
			est store Mig11
		probit y5_reg_5_migrat $migra_var ind_agr, robust
			est store Mig12
		probit y5_reg_5_migrat $migra_var ser_agr, robust
			est store Mig13
		probit y5_reg_5_migrat $migra_var ser_ind, robust
			est store Mig14
			
		outreg2 [Mig1 Mig2 Mig3 Mig4 Mig5 Mig6 Mig7 Mig8 Mig9 Mig10 Mig11 Mig12 Mig13 Mig14] using "$tables/Table A4 - Drivers of internal migration.xls", replace symbol(***, **, *) e(N ll r2_p r2 chi2 p F p) dec(4)
		
		
		